@@ -123,12 +123,17 @@ package Plack::Sandbox::%s;
 END_EVAL
 }
 
+sub _relativize {
+    my $file = shift;
+    $file =~ m!^/! ? $file : "./$file";
+}
+
 sub load_psgi {
     my $stuff = shift;
 
     local $ENV{PLACK_ENV} = $ENV{PLACK_ENV} || 'development';
 
-    my $file = $stuff =~ /^[a-zA-Z0-9\_\:]+$/ ? class_to_file($stuff) : $stuff;
+    my $file = $stuff =~ /^[a-zA-Z0-9\_\:]+$/ ? class_to_file($stuff) : _relativize($stuff);
     my $app = _load_sandbox($file);
     die "Error while loading $file: $@" if $@;
 
@@ -430,19 +435,25 @@ require the file to get PSGI application handler. If the file can't be
 loaded (e.g. file doesn't exist or has a perl syntax error), it will
 throw an exception.
 
+Since version 1.0006, this function would not load PSGI files from
+include paths (C<@INC>) unless it looks like a class name that only
+consists of C<[A-Za-z0-9_:]>. For example:
+
+  Plack::Util::load_psgi("app.psgi");          # ./app.psgi
+  Plack::Util::load_psgi("/path/to/app.psgi"); # /path/to/app.psgi
+  Plack::Util::load_psgi("MyApp::PSGI");       # MyApp/PSGI.pm from @INC
+
 B<Security>: If you give this function a class name or module name
 that is loadable from your system, it will load the module. This could
 lead to a security hole:
 
-  my $psgi = ...; # user-input: consider "Moose.pm"
-  $app = Plack::Util::load_psgi($psgi); # this does 'require "Moose.pm"'!
+  my $psgi = ...; # user-input: consider "Moose"
+  $app = Plack::Util::load_psgi($psgi); # this would lead to 'require "Moose.pm"'!
 
 Generally speaking, passing an external input to this function is
-considered very insecure. But if you really want to do that, be sure
-to validate the argument passed to this function. Also, if you do not
-want to accept an arbitrary class name but only load from a file path,
-make sure that the argument C<$psgi_file_or_class> begins with C</> so
-that Perl's built-in do function won't search the include path.
+considered very insecure. If you really want to do that, validate that
+a given file name contains dots (like C<foo.psgi>) and also turn it
+into a full path in your caller's code.
 
 =item run_app
 
